@@ -546,6 +546,7 @@ class BaseInlineFormSetWithAddMoreButton(BaseInlineFormSet):
     $('#{button_id}').click(function() {{
         var form_idx = $('#id_{self.prefix}-TOTAL_FORMS').val();
         var empty_form = document.getElementById('{empty_form_id}').innerHTML.replace(/__prefix__/g, form_idx);        
+        
         var d1 = document.getElementById('{div_name}');
         d1.insertAdjacentHTML('afterend', empty_form);
         $('#id_{self.prefix}-TOTAL_FORMS').val(parseInt(form_idx) + 1);
@@ -567,7 +568,8 @@ from django.utils.safestring import mark_safe
 
 class DataTransform(forms.ModelForm):
     id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+                         initial=uuid.uuid4())
     accessory = forms.ModelChoiceField(required=False, queryset=Accessory.objects.all(),
                                        widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
@@ -578,7 +580,12 @@ class DataTransform(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         print('Init Data Transform')
+
         super(DataTransform, self).__init__(*args, **kwargs)
+        if self.instance.parent is not None:
+            self.accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
+                                                    widget=forms.HiddenInput(attrs={'class': 'form-control'}),
+                                                    initial=self.instance.accessory.pk)
         # types = list(
         #     DataTransformerTypes.objects.all().values_list('type', 'type'))
         # self.fields['type'] = ChoiceField(choices=tuple(types))
@@ -714,7 +721,7 @@ dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransf
 
 class DataTransformRoot(forms.ModelForm):
     id = forms.CharField(required=False,
-                         widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+                         widget=forms.HiddenInput(attrs={'class': 'form-control'}),initial=uuid.uuid4())
     accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
                                        widget=forms.HiddenInput(attrs={'class': 'form-control'}))
     type = forms.ModelChoiceField(required=True, queryset=DataTransformerTypes.objects.all())
@@ -723,6 +730,9 @@ class DataTransformRoot(forms.ModelForm):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
+        self.accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
+                                       widget=forms.HiddenInput(attrs={'class': 'form-control'}), initial=self.instance.accessory.pk)
+
         # types = list(
         #     DataTransformerTypes.objects.all().values_list('type', 'type'))
         # self.fields['type'] = ChoiceField(choices=tuple(types))
@@ -748,6 +758,8 @@ class DataTransformRoot(forms.ModelForm):
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset',
+                    initial=[{'parent': str(self.instance.pk), 'accessory': str(self.instance.accessory.id),
+                              'id': str(uuid.uuid4())}],
                 )
                 self.nested_data_transformer_form.extra = 0
         except Exception as e:
